@@ -1,3 +1,8 @@
+### https://realpython.com/pypi-publish-python-package/
+## if you need a package that should be executable like "python converter" then there should be a __main__.py file. read the above article.
+
+import test
+
 def c2f(n):
     """
     celsius to fahrenheit
@@ -24,4 +29,4 @@ def add_temp(n):
     a = f2c(n)
     b = c2f(n)
     r = a+b
-    return r
\ No newline at end of file
+    return r
